# Test

For more details, please refer to this video: https://www.youtube.com/watch?v=rR4n-0KYeKQ

```
$ uv sync
$ uv pip install -e .
$ uv run pytest tests
$ uv run pytest --capture=tee-sys tests
```